#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

from z3c.form.field import Fields

from pyams_darkgreen_theme.features.footer import IDarkGreenThemeFooterLegalsMenu, \
    IDarkGreenThemeFooterMenusContainer, \
    IDarkGreenThemeFooterRendererSettings
from pyams_content.features.footer.zmi import FooterSettingsRendererSettingsEditForm
from pyams_content.features.menu.zmi import IMenuLinksView, IMenusView, LinksTable, MenuLinksView, \
    MenusTable, \
    MenusView
from pyams_form.interfaces.form import IInnerSubForm
from pyams_portal.interfaces import MANAGE_TEMPLATE_PERMISSION
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.adapter import adapter_config
from pyams_zmi.form import InnerAdminEditForm


__docformat__ = 'restructuredtext'

from pyams_darkgreen_theme import _


@adapter_config(name='simple-footer-properties',
                context=(IDarkGreenThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
class DarkGreenThemeFooterPropertiesEditForm(InnerAdminEditForm):
    """DarkGreen theme footer properties edit form"""

    legend = None
    edit_permission = MANAGE_TEMPLATE_PERMISSION
    weight = 1

    fields = Fields(IDarkGreenThemeFooterRendererSettings)


#
# Footer menus table view
#

@adapter_config(name=' darkgreen-footer-menus',
                context=(IDarkGreenThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++menus',
                context=(IDarkGreenThemeFooterMenusContainer, IPyAMSLayer),
                provides=IMenusView)
class DarkGreenThemeFooterMenusView(MenusView):
    """DarkGreen theme footer menus view"""

    title = _("Footer menus")

    table_class = MenusTable
    weight = 10


#
# Footer legal links table view
#

class LegalLinksTable(LinksTable):
    """Legal links associations table"""

    associations_name = 'legals'


@adapter_config(name=' darkgreen-footer-legals',
                context=(IDarkGreenThemeFooterRendererSettings, IPyAMSLayer, FooterSettingsRendererSettingsEditForm),
                provides=IInnerSubForm)
@adapter_config(name='++ass++legals',
                context=(IDarkGreenThemeFooterLegalsMenu, IPyAMSLayer),
                provides=IMenuLinksView)
class DarkGreenThemeFooterLegalsView(MenuLinksView):
    """DarkGreen theme footer legals view"""

    title = _("Legal links menus")

    table_class = LegalLinksTable
    weight = 15
